summaryrefslogtreecommitdiffstats
path: root/yt/cpp/mapreduce/interface/client_method_options.h
diff options
context:
space:
mode:
authorhiddenpath <[email protected]>2024-12-23 15:18:22 +0300
committerhiddenpath <[email protected]>2024-12-23 16:12:22 +0300
commitfac5ce91c704b4a1d3aa2f059842df3ba3a955bd (patch)
tree00fa7a628e7aa63df387c095cf8a2c7cbac3e3e9 /yt/cpp/mapreduce/interface/client_method_options.h
parentfbc08848ae794f01d5107e6b556045e62fd36afe (diff)
YT-23616: Move read_blob_table and read_file to THttpRawClient
commit_hash:6c9209d019fa324c9ae4f182b18e7d089a32937d
Diffstat (limited to 'yt/cpp/mapreduce/interface/client_method_options.h')
-rw-r--r--yt/cpp/mapreduce/interface/client_method_options.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/yt/cpp/mapreduce/interface/client_method_options.h b/yt/cpp/mapreduce/interface/client_method_options.h
index 9bfb79753dd..d457bf5f434 100644
--- a/yt/cpp/mapreduce/interface/client_method_options.h
+++ b/yt/cpp/mapreduce/interface/client_method_options.h
@@ -287,9 +287,12 @@ struct TBlobTableReaderOptions
///
/// All blob parts except the last part of the blob must be of this size
/// otherwise blob table reader emits error.
- FLUENT_FIELD_DEFAULT(ui64, PartSize, 4 * 1024 * 1024);
+ FLUENT_FIELD_DEFAULT(i64, PartSize, 4 * 1024 * 1024);
- /// @brief Offset from which to start reading
+ /// @brief Part index from which to start reading.
+ FLUENT_FIELD_DEFAULT(i64, StartPartIndex, 0);
+
+ /// @brief Offset from which to start reading.
FLUENT_FIELD_DEFAULT(i64, Offset, 0);
};
@@ -468,7 +471,7 @@ struct TFileReaderOptions
/// @brief Offset to start reading from.
///
/// By default reading is started from the beginning of the file.
- FLUENT_FIELD_OPTION(i64, Offset);
+ FLUENT_FIELD_DEFAULT(i64, Offset, 0);
///
/// @brief Maximum length to read.